from pydantic import BaseModel, Field
from datetime import datetime
from typing import Optional
from rvn.config.settings import EXCEL_COLONNES, PASSPHRASE
from itsdangerous.url_safe import URLSafeSerializer
import hashlib
import logging


logger = logging.getLogger(__name__)


class ExcelUEO(BaseModel):
    numero_etudiant: int = Field(alias=EXCEL_COLONNES['numero_etudiant'])
    notes: float = Field(alias=EXCEL_COLONNES['notes'])
    prenom: str = Field(alias=EXCEL_COLONNES['prenom'])
    nom: str = Field(alias=EXCEL_COLONNES['nom'])
    date_naissance: datetime = Field(alias=EXCEL_COLONNES['date_naissance'])
    composante: str = Field(alias=EXCEL_COLONNES['composante'])
    libelle_parcours: str = Field(alias=EXCEL_COLONNES['libelle_parcours'])
    libelle_ueo: str = Field(alias=EXCEL_COLONNES['libelle_ueo'])
    dk: Optional[str] = Field(default=None, repr=False)
    sk: Optional[str] = Field(default=None, repr=False)

    def model_post_init(self, ctx) -> None:
        logger.debug(f'Post-Initialisation du model ExcelUEO {self.numero_etudiant}')
        s = URLSafeSerializer(PASSPHRASE, salt='ueo')
        self.dk = s.dumps((self.numero_etudiant, self.date_naissance.strftime('%d/%m/%Y'), self.libelle_ueo, self.notes))
        self.sk = hashlib.shake_256((str(self.numero_etudiant)+self.libelle_ueo).encode()).hexdigest(6)

